# Generated by Django 5.1.4 on 2025-06-02 16:25

from django.db import migrations, models


def convert_boolean_to_enum(apps, schema_editor):
    """Convert boolean removes field to enum values"""
    Status = apps.get_model("birds", "Status")

    # Set all removal types to expected for now
    for status in Status.objects.all():
        if status.removes:
            status.removes_new = "expected"
        else:
            status.removes_new = None
        status.save()


def reverse_enum_to_boolean(apps, schema_editor):
    """Reverse the conversion for rollback"""
    Status = apps.get_model("birds", "Status")

    for status in Status.objects.all():
        # Any non-None value becomes True
        status.removes = status.removes_new is not None
        status.save()


class Migration(migrations.Migration):
    dependencies = [
        ("birds", "0021_alter_measurement_event_alter_sample_date"),
    ]

    operations = [
        # Step 1: Add the new enum field
        migrations.AddField(
            model_name="status",
            name="removes_new",
            field=models.CharField(
                max_length=10,
                choices=[
                    (None, "Not a removal"),
                    ("expected", "Expected death or removal"),
                    ("unexpected", "Unexpected death"),
                ],
                null=True,
                blank=True,
                default=None,
                help_text="type of removal event, or None for events that don't remove an animal",
            ),
        ),
        # Step 2: Convert data from boolean to enum
        migrations.RunPython(convert_boolean_to_enum, reverse_enum_to_boolean),
        # Step 3: Remove the old boolean field
        migrations.RemoveField(
            model_name="status",
            name="removes",
        ),
        # Step 4: Rename the new field to the original name
        migrations.RenameField(
            model_name="status",
            old_name="removes_new",
            new_name="removes",
        ),
    ]
