# Generated by Django 5.1.4 on 2025-06-03 19:26

from django.db import migrations, models


def convert_boolean_to_enum(apps, schema_editor):
    """Convert boolean adds field to enum values"""
    Status = apps.get_model("birds", "Status")

    # Set all addition types to birth for now
    for status in Status.objects.all():
        if status.adds:
            status.adds_new = "birth"
        else:
            status.adds_new = None
        status.save()


def reverse_enum_to_boolean(apps, schema_editor):
    """Reverse the conversion for rollback"""
    Status = apps.get_model("birds", "Status")

    for status in Status.objects.all():
        # Any non-None value becomes True
        status.adds = status.adds_new is not None
        status.save()


class Migration(migrations.Migration):
    dependencies = [
        ("birds", "0022_status_removes_to_enum_20250602_1225"),
    ]

    operations = [
        # Step 1: Add the new enum field
        migrations.AddField(
            model_name="status",
            name="adds_new",
            field=models.CharField(
                max_length=10,
                choices=[
                    (None, "Not an addition"),
                    ("egg", "Unborn animal generated within the colony"),
                    ("birth", "Animal born within the colony"),
                    ("transfer", "Animal transferred into the colony from outside"),
                ],
                help_text="type of addition event, or None for events that don't add an animal",
                null=True,
                blank=True,
                default=None,
            ),
        ),
        # Step 2: Convert data from boolean to enum
        migrations.RunPython(convert_boolean_to_enum, reverse_enum_to_boolean),
        # Step 3: Remove the old boolean field
        migrations.RemoveField(
            model_name="status",
            name="adds",
        ),
        # Step 4: Rename the new field to the original name
        migrations.RenameField(
            model_name="status",
            old_name="adds_new",
            new_name="adds",
        ),
    ]
