# Generated by Django 5.1.4 on 2025-06-09 16:03
import datetime

from django.db import migrations, models


def fix_parent_created_after_child(apps, schema_editor):
    """For every parent with a created timestamp later than its kids, change to one day before child was created"""
    Animal = apps.get_model("birds", "Animal")
    qs = Animal.objects.filter(children__created__lte=models.F("created")).distinct()
    for animal in qs:
        first_child = animal.children.order_by("created").first()
        assert animal.created >= first_child.created
        # print(f"{animal.name} has timestamp of {animal.created}; first child {first_child.name} was created {first_child.created}")
        animal.created = first_child.created - datetime.timedelta(days=1)
        animal.save()


class Migration(migrations.Migration):
    dependencies = [
        ("birds", "0025_parent_parent_idx_parent_child_idx"),
    ]

    operations = [migrations.RunPython(fix_parent_created_after_child)]
